#include <imsls.h>
#include <stdlib.h>
#include <stdio.h>

int main()
{
   int i;
   int maxlag = 20;
   int n_obs = 100;
   int p;
   float w[176][2];
   float z[100];
   float *parameters = NULL;
   float avar, aic, constant;
   float ar[20];

   /* get wolfer sunspot data */
   imsls_f_data_sets (2, IMSLS_X_COL_DIM, 2,
      IMSLS_RETURN_USER, w,
      0);

   for (i=0; i<n_obs; i++)
      z[i] = w[21+i][1];

   /* Compute AR parameters for minimum AIC by method of moments */

   printf("\n\nAIC Automatic Order selection\n");
   printf("AR coefficients estimated using method of moments\n");

   parameters = imsls_f_auto_uni_ar(n_obs, z, maxlag, &p,
      IMSLS_VAR_NOISE, &avar,
      IMSLS_METHOD, 0,
      IMSLS_AIC, &aic,
      0);

   printf("Order selected: %d\n", p);
   printf("AIC =  %11.4f,  Variance = %11.4f\n", aic, avar);
   printf("Constant estimate is %11.4f.\n", parameters[0]);
   imsls_f_write_matrix(
      "Final AR coefficients estimated by method of moments", 
      p, 1, &parameters[1], 0);

   if (parameters)
   {
      imsls_free(parameters);
      parameters = NULL;
   }

   /* Compute AR parameters for minimum AIC 
      by method of least squares */

   printf("\n\nAIC Automatic Order selection\n");
   printf("AR coefficients estimated using method of least squares\n");

   imsls_f_auto_uni_ar(n_obs, z, maxlag, &p,
      IMSLS_VAR_NOISE, &avar,
      IMSLS_METHOD, 1,
      IMSLS_AIC, &aic,
      IMSLS_RETURN_USER, &constant, ar,
      0);

   printf("Order selected: %d\n", p);
   printf("AIC =  %11.4f,  Variance = %11.4f\n", aic, avar);
   printf("Constant estimate is %11.4f.\n", constant);
   imsls_f_write_matrix(
      "Final AR coefficients estimated by method of least squares", 
      p, 1, ar, 0);

   /* Compute AR parameters for minimum AIC 
      by maximum likelihood estimation */

   printf("\n\nAIC Automatic Order selection\n");
   printf("AR coefficients estimated using maximum likelihood\n");

   imsls_f_auto_uni_ar(n_obs, z, maxlag, &p,
      IMSLS_VAR_NOISE, &avar,
      IMSLS_METHOD, 2,
      IMSLS_AIC, &aic,
      IMSLS_RETURN_USER, &constant, ar,
      0);

   printf("Order selected: %d\n", p);
   printf("AIC =  %11.4f,  Variance = %11.4f\n", aic, avar);
   printf("Constant estimate is %11.4f.\n", constant);
   imsls_f_write_matrix(
      "Final AR coefficients estimated by maximum likelihood", 
      p, 1, ar, 0);                       

}